# mypy-boto3-mediaconnect

[![PyPI - mypy-boto3-mediaconnect](https://img.shields.io/pypi/v/mypy-boto3-mediaconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconnect)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-mediaconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconnect)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MediaConnect 1.17.14](https://boto3.amazonaws.com/v1/documentation/api/1.17.14/reference/services/mediaconnect.html#MediaConnect) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-mediaconnect](#mypy-boto3-mediaconnect)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `MediaConnect` service.

```bash
python -m pip install boto3-stubs[mediaconnect]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[mediaconnect]` in your environment: `python -m pip install 'boto3-stubs[mediaconnect]'`

Both type checking and auto-complete should work for `MediaConnect` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[mediaconnect]` in your environment: `python -m pip install 'boto3-stubs[mediaconnect]'`

Both type checking and auto-complete should work for `MediaConnect` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[mediaconnect]` in your environment: `python -m pip install 'boto3-stubs[mediaconnect]'`
- Run `mypy` as usual

Type checking should work for `MediaConnect` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[mediaconnect]` in your environment: `python -m pip install 'boto3-stubs[mediaconnect]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaConnect` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`MediaConnectClient` provides annotations for `boto3.client("mediaconnect")`.

```python
import boto3

from mypy_boto3_mediaconnect import MediaConnectClient

client: MediaConnectClient = boto3.client("mediaconnect")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaConnectClient = session.client("mediaconnect")
```

### Paginators annotations

`mypy_boto3_mediaconnect.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_mediaconnect import MediaConnectClient
from mypy_boto3_mediaconnect.paginator import (
    ListEntitlementsPaginator,
    ListFlowsPaginator,
    ListOfferingsPaginator,
    ListReservationsPaginator,
)

client: MediaConnectClient = boto3.client("mediaconnect")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_entitlements_paginator: ListEntitlementsPaginator = client.get_paginator("list_entitlements")
list_flows_paginator: ListFlowsPaginator = client.get_paginator("list_flows")
list_offerings_paginator: ListOfferingsPaginator = client.get_paginator("list_offerings")
list_reservations_paginator: ListReservationsPaginator = client.get_paginator("list_reservations")
```







### Typed dictionations

`mypy_boto3_mediaconnect.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_mediaconnect.type_defs import (
    EncryptionTypeDef,
    EntitlementTypeDef,
    FailoverConfigTypeDef,
    FlowTypeDef,
    ListedEntitlementTypeDef,
    ListedFlowTypeDef,
    MessagesTypeDef,
    OfferingTypeDef,
    OutputTypeDef,
    ReservationTypeDef,
    ResourceSpecificationTypeDef,
    ResponseMetadata,
    SourceTypeDef,
    TransportTypeDef,
    VpcInterfaceAttachmentTypeDef,
    VpcInterfaceTypeDef,
    AddFlowOutputsResponseTypeDef,
    AddFlowSourcesResponseTypeDef,
    AddFlowVpcInterfacesResponseTypeDef,
    AddOutputRequestTypeDef,
    CreateFlowResponseTypeDef,
    DeleteFlowResponseTypeDef,
    DescribeFlowResponseTypeDef,
    DescribeOfferingResponseTypeDef,
    DescribeReservationResponseTypeDef,
    GrantEntitlementRequestTypeDef,
    GrantFlowEntitlementsResponseTypeDef,
    ListEntitlementsResponseTypeDef,
    ListFlowsResponseTypeDef,
    ListOfferingsResponseTypeDef,
    ListReservationsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PurchaseOfferingResponseTypeDef,
    RemoveFlowOutputResponseTypeDef,
    RemoveFlowSourceResponseTypeDef,
    RemoveFlowVpcInterfaceResponseTypeDef,
    RevokeFlowEntitlementResponseTypeDef,
    SetSourceRequestTypeDef,
    StartFlowResponseTypeDef,
    StopFlowResponseTypeDef,
    UpdateEncryptionTypeDef,
    UpdateFailoverConfigTypeDef,
    UpdateFlowEntitlementResponseTypeDef,
    UpdateFlowOutputResponseTypeDef,
    UpdateFlowResponseTypeDef,
    UpdateFlowSourceResponseTypeDef,
    VpcInterfaceRequestTypeDef,
)

def get_structure() -> EncryptionTypeDef:
    return {
      ...
    }
```
